SystemOrganization addCategory: #ConfigurationOfWidgets!

Object subclass: #ConfigurationOfWidgets
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfWidgets'!

!ConfigurationOfWidgets class methodsFor: 'private' stamp: 'mt 10/6/2010 16:58:32.632'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfWidgets class methodsFor: 'private' stamp: 'mt 10/6/2010 16:58:32.786'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfWidgets class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:58:32.877'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfWidgets class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:58:32.946'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfWidgets class methodsFor: 'loading' stamp: 'mt 10/6/2010 16:58:33.144'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfWidgets class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 16:58:33.04'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfWidgets class methodsFor: 'accessing' stamp: 'mt 10/6/2010 16:58:33.197'!
project

	^self new project! !

!ConfigurationOfWidgets class methodsFor: 'unloading Metacello' stamp: 'mt 10/6/2010 16:58:33.302'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfWidgets methodsFor: 'baselines' stamp: 'mt 12/4/2010 10:21:04.916'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec
			package: 'Icons';
			package: 'Widgets' with: [spec requires: #('Animations' 'Signals' 'SwaUtil')].

		spec group: 'default' with: #('Widgets').
		spec group: 'full' with: #('Widgets' 'Icons')].! !

!ConfigurationOfWidgets methodsFor: 'baselines' stamp: 'mt 12/4/2010 10:24:10.893'!
baseline110: spec 
	<version: '1.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'VB-Regex' with: [spec repository: 'http://www.squeaksource.com/Regex'].
					
		spec
			package: 'Icons';
			package: 'Widgets' with: [spec requires: #('Animations' 'Signals' 'VB-Regex')].

		spec group: 'default' with: #('Widgets').
		spec group: 'full' with: #('Widgets' 'Icons')].! !

!ConfigurationOfWidgets methodsFor: 'accessing' stamp: 'mt 10/6/2010 16:58:32.43'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfWidgets methodsFor: 'versions' stamp: 'mt 12/4/2010 10:19:50.69'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.1';
			project: 'Animations' with: '1.0';
			project: 'SwaUtil' with: '1.0.1'.
		
		spec
			package: 'Widgets' with: 'Widgets-mt.64';
			package: 'Icons' with: 'Icons-mt.1'].! !

!ConfigurationOfWidgets methodsFor: 'versions' stamp: 'mt 12/4/2010 10:22:39.059'!
version110: spec

	<version: '1.1' imports: #('1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.1';
			project: 'Animations' with: '1.0.1';
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17'].! !
